@@ -1,7 +1,9 @@
+import os
 from enum import auto, Enum as PyEnum
 from typing import Any, List, TYPE_CHECKING, Dict
 
-from geoalchemy2 import Geometry
+import sqlalchemy.orm.session
+from geoalchemy2 import Geometry, WKBElement
 from sqlalchemy import (
     BigInteger,
     Boolean,
@@ -12,6 +14,8 @@ from sqlalchemy import (
     ForeignKey,
     Integer,
     Text,
+    func,
+    JSON,
 )
 from sqlalchemy.orm import Mapped, mapped_column, relationship
 from sqlalchemy.dialects import postgresql
@@ -31,7 +35,9 @@ class Line(Base):
 
     __tablename__ = "Line"
 
-    id: Mapped[int] = mapped_column(BigInteger, primary_key=True)
+    id: Mapped[int] = mapped_column(
+        BigInteger().with_variant(Integer, "sqlite"), primary_key=True
+    )
     """The unique identifier of the battery type. Auto-incremented."""
 
     scenario_id: Mapped[int] = mapped_column(ForeignKey("Scenario.id"), nullable=False)
@@ -61,7 +67,9 @@ class Route(Base):
 
     __tablename__ = "Route"
 
-    id: Mapped[int] = mapped_column(BigInteger, primary_key=True)
+    id: Mapped[int] = mapped_column(
+        BigInteger().with_variant(Integer, "sqlite"), primary_key=True
+    )
     """The unique identifier of the battery type. Auto-incremented."""
 
     scenario_id: Mapped[int] = mapped_column(ForeignKey("Scenario.id"), nullable=False)
@@ -107,7 +115,7 @@ class Route(Base):
     """The length of the route in meters."""
 
     geom: Mapped[Geometry] = mapped_column(
-        Geometry("LINESTRINGZ", srid=4326), nullable=True
+        Geometry("LINESTRING", srid=4326), nullable=True
     )
     """
     The shape of the route as a polyline. If set, the length of this shape must be equal to :attr:`Route.distance`.
@@ -144,6 +152,48 @@ class Route(Base):
     def __repr__(self) -> str:
         return f"<Route(id={self.id}, name={self.name})>"
 
+    @staticmethod
+    def calculate_length(
+        session: sqlalchemy.orm.session.Session, linestring: str
+    ) -> float:
+        """
+        Portable function to calculate the length of a linestring in meters. It adapts to whether the database uses
+        PostGIS or SpatiaLite.
+
+        :param session: An open SQLAlchemy session.
+        :param linestring: A string representation of a linestring in WKT format.
+        :return: The length of the linestring in meters.
+        """
+        if session.bind is None or session.bind.dialect is None:
+            raise ValueError("Session is not bound to a database.")
+        if session.bind.dialect.name == "postgresql":
+            # PostGIS
+            distance = session.query(
+                func.ST_Length(func.ST_GeomFromText(linestring, 4326), True)
+            ).scalar()
+            if distance is None:
+                raise ValueError("Failed to calculate length of linestring.")
+            assert isinstance(distance, float), "Distance should be a float."
+            return distance
+        elif session.bind.dialect.name == "sqlite":
+            # SpatiaLite
+            # The linestring must be in WKT format, and be a "LINESTRING"
+            if "LINESTRING" not in linestring:
+                raise ValueError(
+                    "The linestring must be in WKT format and be a 'LINESTRING'."
+                )
+            distance = session.query(
+                func.GeodesicLength(func.ST_GeomFromText(linestring, 4326))
+            ).scalar()
+            if distance is None:
+                raise ValueError("Failed to calculate length of linestring.")
+            assert isinstance(distance, float), "Distance should be a float."
+            return distance
+        else:
+            raise NotImplementedError(
+                f"Length calculation not implemented for dialect {session.bind.dialect.name}"
+            )
+
 
 @event.listens_for(Route, "before_insert")
 @event.listens_for(Route, "before_update")
@@ -258,7 +308,9 @@ class Station(Base):
 
     __tablename__ = "Station"
 
-    id: Mapped[int] = mapped_column(BigInteger, primary_key=True)
+    id: Mapped[int] = mapped_column(
+        BigInteger().with_variant(Integer, "sqlite"), primary_key=True
+    )
     """The unique identifier of the battery type. Auto-incremented."""
 
     scenario_id: Mapped[int] = mapped_column(ForeignKey("Scenario.id"), nullable=False)
@@ -271,7 +323,7 @@ class Station(Base):
     name_short: Mapped[str] = mapped_column(Text, nullable=True)
     """The short name of the station (if available)."""
 
-    geom: Mapped[Geometry] = mapped_column(Geometry("POINTZ", srid=4326), nullable=True)
+    geom: Mapped[Geometry] = mapped_column(Geometry("POINT", srid=4326), nullable=True)
     """The (optional) location of the station as a point. Use WGS84 coordinates (EPSG:4326)."""
 
     is_electrified = mapped_column(Boolean, nullable=False)
@@ -332,7 +384,7 @@ class Station(Base):
     """The charging point type. This is used to represent the different types of charging points installed at stations or areas. It is mainly relevant for TCO calculations."""
 
     tco_parameters: Mapped[Dict[str, Any]] = mapped_column(
-        postgresql.JSONB,
+        postgresql.JSONB().with_variant(JSON, "sqlite"),  # type: ignore
         nullable=True,
         server_default="""
         {
@@ -426,7 +478,9 @@ class AssocRouteStation(Base):
 
     __tablename__ = "AssocRouteStation"
 
-    id: Mapped[int] = mapped_column(BigInteger, primary_key=True)
+    id: Mapped[int] = mapped_column(
+        BigInteger().with_variant(Integer, "sqlite"), primary_key=True
+    )
     """The unique identifier of the association. Auto-incremented."""
 
     scenario_id: Mapped[int] = mapped_column(ForeignKey("Scenario.id"), nullable=False)
@@ -449,7 +503,7 @@ class AssocRouteStation(Base):
     """The station."""
 
     location: Mapped[Geometry] = mapped_column(
-        Geometry("POINTZ", srid=4326), nullable=True
+        Geometry("POINT", srid=4326), nullable=True
     )
     """An optional precise location of the this route's stop at the station. Use WGS84 coordinates (EPSG:4326)."""
 
