@@ -15,10 +15,11 @@ from sqlalchemy import (
     Interval,
     Text,
     UniqueConstraint,
+    Integer,
 )
 from sqlalchemy.orm import Mapped, mapped_column, relationship
 
-from eflips.model import Base, ConsistencyWarning
+from eflips.model import Base, ConsistencyWarning, TimeStampWithTz
 
 if TYPE_CHECKING:
     from eflips.model import Event, Vehicle, VehicleType, Scenario, Station, Route
@@ -34,7 +35,9 @@ class StopTime(Base):
 
     __tablename__ = "StopTime"
 
-    id: Mapped[int] = mapped_column(BigInteger, primary_key=True)
+    id: Mapped[int] = mapped_column(
+        BigInteger().with_variant(Integer, "sqlite"), primary_key=True
+    )
     """The unique identifier of the battery type. Auto-incremented."""
 
     scenario_id: Mapped[int] = mapped_column(ForeignKey("Scenario.id"), nullable=False)
@@ -53,7 +56,7 @@ class StopTime(Base):
     """The trip."""
 
     arrival_time: Mapped[datetime] = mapped_column(
-        DateTime(timezone=True), nullable=False
+        DateTime(timezone=True).with_variant(TimeStampWithTz, "sqlite"), nullable=False
     )
     """The arrival time at the station."""
 
@@ -100,7 +103,9 @@ class Trip(Base):
 
     __tablename__ = "Trip"
 
-    id: Mapped[int] = mapped_column(BigInteger, primary_key=True)
+    id: Mapped[int] = mapped_column(
+        BigInteger().with_variant(Integer, "sqlite"), primary_key=True
+    )
     """The unique identifier of the battery type. Auto-incremented."""
 
     scenario_id: Mapped[int] = mapped_column(ForeignKey("Scenario.id"), nullable=False)
@@ -123,7 +128,9 @@ class Trip(Base):
     """The rotation."""
 
     departure_time: Mapped[datetime] = mapped_column(
-        DateTime(timezone=True), nullable=False, index=True
+        DateTime(timezone=True).with_variant(TimeStampWithTz, "sqlite"),
+        nullable=False,
+        index=True,
     )
     """
     The departure time at the first station.
@@ -133,7 +140,9 @@ class Trip(Base):
     """
 
     arrival_time: Mapped[datetime] = mapped_column(
-        DateTime(timezone=True), nullable=False, index=True
+        DateTime(timezone=True).with_variant(TimeStampWithTz, "sqlite"),
+        nullable=False,
+        index=True,
     )
     """
     The arrival time at the last station.
@@ -299,7 +308,9 @@ class Rotation(Base):
 
     __tablename__ = "Rotation"
 
-    id: Mapped[int] = mapped_column(BigInteger, primary_key=True)
+    id: Mapped[int] = mapped_column(
+        BigInteger().with_variant(Integer, "sqlite"), primary_key=True
+    )
     """The unique identifier of the battery type. Auto-incremented."""
 
     scenario_id: Mapped[int] = mapped_column(ForeignKey("Scenario.id"), nullable=False)
